---
title: Model All Comparisons
---

![Model All Comparisons](../baseline/model_all_comparisons.png)

??? imports "Imports"
    ```python
    --8<--
    examples/model_ex/model_all_comparisons.py:imports
    --8<--
    ```

??? setup "Setup"
    ```python
    --8<--
    examples/model_ex/model_all_comparisons.py:setup
    --8<--
    ```

!!! tip "Code"
    ```python
    --8<--
    examples/model_ex/model_all_comparisons.py:plot_body
    --8<--
    ```

??? code "Full code"
    ```python
    --8<--
    examples/model_ex/model_all_comparisons.py:full_code
    --8<--
    ```
